local CustomDecoration = ...

_PrefixAsset = "CUSTOM_DECORATION_V3"
_CommonFlagPrefix = "CUSTOM_FLAG_V3"
_CommonWindowPrefix = "CUSTOM_WINDOW_V3"
_CommonDoorPrefix = "CUSTOM_DOOR_V3"
_CommonChurchPrefix = "CUSTOM_CHURCH_V3"

-- Register all stone gate set building parts and their properties
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
CustomDecoration:dofile(_scriptFolder .. "/compDecoration.lua")
CustomDecoration:dofile(_scriptFolder .. "/decoration.lua")
CustomDecoration:dofile(_scriptFolder .. "/compLeadWire.lua")
CustomDecoration:dofile(_scriptFolder .. "/leadWire.lua")
CustomDecoration:dofile(_scriptFolder .. "/compFlagFlaping.lua", _CommonFlagPrefix)
CustomDecoration:dofile(_scriptFolder .. "/flags.lua", _CommonFlagPrefix, _CommonWindowPrefix)
CustomDecoration:dofile(_scriptFolder .. "/corner.lua")

function configureMaterielSetList(_colorRoof, _colorWall, _colorFrame, _colorFlag, _isDefaultMaterial)
    function configureMaterial(_core, _colorMaterial)
        if _isDefaultMaterial then
            return  _CommonWindowPrefix .. "_" .. _core .. "_" .. _colorMaterial .. "_MATERIAL"
        else
            return  _CommonWindowPrefix .. "_DECORATION_" .. _colorMaterial .. "_MATERIAL"
        end
    end
    return {
                SetName = _PrefixAsset .. "_" .. _colorRoof .. "_" .. _colorWall .. "_" .. _colorFrame,
                MaterialList = {
                    configureMaterial("STONE_WINDOW", _colorRoof),
                    configureMaterial("WOODEN_WINDOW", _colorRoof),
                    configureMaterial("WOODEN_ENTRANCE", _colorRoof),

                    configureMaterial("STONE_DECORATION", _colorWall),
                    configureMaterial("STONE_BUTTRESS", _colorWall),

                    configureMaterial("STONE_DECORATION", _colorFrame),
                    configureMaterial("STONE_DOORS", _colorFrame),
-- not used standalone                    configureMaterial("CORNER"),
                    configureMaterial("STAINED_GLASS", _colorFrame),
                    configureMaterial("FLAPING", _colorFlag),
                }
    }
end

CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_LEAD_WIRE_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_STONE_MONUMENT_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_WOODEN_MONUMENT_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_IRON_MONUMENT_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_STAINED_GLASS_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _PrefixAsset .. "_TEXTILE_MONUMENT_PARTSETLIST_NAME")
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", _CommonChurchPrefix .. "_ADDITION_NAME")
CustomDecoration:registerAsset({
    DataType = "BUILDING",
    Id = _PrefixAsset .. "_MONUMENT",
    Name = _PrefixAsset .. "_MONUMENT_NAME",
    Description = _PrefixAsset .. "_MONUMENT_DESC",
    BuildingType = "MODS",
    AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
    AssetMiniatureBuildingPart = _PrefixAsset .. "_PFENETRE_ROOT_PART",
    AssetBuildingPartList = {
		            _PrefixAsset .. "_LEAD_WIRE_ROOT_PART",

		            _PrefixAsset .. "_SFENETRE_ROOT_PART",
		            _PrefixAsset .. "_LFENETRE_ROOT_PART",
		            _PrefixAsset .. "_PFENETRE_ROOT_PART",
		            _PrefixAsset .. "_STONE_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_ARROWSLIT_ROOT_PART",
		            _PrefixAsset .. "_BALCONY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_B_ROOT_PART",
		            _PrefixAsset .. "_TURRET_ROOT_PART",
		            _PrefixAsset .. "_BUTTRESS_ROOT_PART",
		            _PrefixAsset .. "_BUTTRESS_LARGE_ROOT_PART",
		            _PrefixAsset .. "_BUTTRESS_CORNER_ROOT_PART",
		            _PrefixAsset .. "_DOOR_A_ROOT_PART",
		            _PrefixAsset .. "_DOOR_B_ROOT_PART",

		            _PrefixAsset .. "_WOODEN_DOOR_C_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_D_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_E_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_AMERICAN_DOOR_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_SMALL_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_MEDIUM_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_LARGE_WINDOW_WITH_BAR_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_WITH_AWNING_SHUTTER_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_WITH_GLASS_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_BOX_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_LARGE_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_POINTED_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_AMERICAN_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_STAIRS_1_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_WHITE_ROOT_PART", -- whith white chalk wall
		            _PrefixAsset .. "_MEDIUM_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_MEDIUM_LUCARNE_WHITE_ROOT_PART",
		            _PrefixAsset .. "_LARGE_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LARGE_LUCARNE_WHITE_ROOT_PART",

                        _PrefixAsset .. "_FINIAL1_ROOT_PART",
		            _PrefixAsset .. "_FINIAL2_ROOT_PART",
		            _PrefixAsset .. "_FINIAL3_ROOT_PART",

                        _PrefixAsset .. "_STAINED_GLASS_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_2_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_3_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_4_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_8_ROOT_PART",
		            _PrefixAsset .. "_SPLENDOR_2_ROOT_PART",
		            _PrefixAsset .. "_P_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_2_ROOT_PART",

		            _CommonFlagPrefix .. "_FLAME_ROOT_PART",
    },
    MaterialSetList = {
            configureMaterielSetList("RED_TILE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "RED_FLAG", true), -- default material list
            configureMaterielSetList("BLUE_TILE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "BLUE_FLAG", false),
            configureMaterielSetList("BROWN_TILE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "GREEN_FLAG", false),
            configureMaterielSetList("LIGHT_GREY_TILE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "ORANGE_FLAG", false),
            configureMaterielSetList("DARK_GREY_TILE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "PURPLE_FLAG", false),
            configureMaterielSetList("RED_SHINGLE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "TURQUOISE_FLAG", false),
            configureMaterielSetList("BLUE_SHINGLE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "RED_FLAG", false),
            configureMaterielSetList("BROWN_SHINGLE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "BLUE_FLAG", false),
            configureMaterielSetList("YELLOW_SHINGLE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "GREEN_FLAG", false),
            configureMaterielSetList("GREEN_SHINGLE_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "ORANGE_FLAG", false),
            configureMaterielSetList("WOODEN_MANOR_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "PURPLE_FLAG", false),
            configureMaterielSetList("STONE_MANOR_ROOF", "STONE_MANOR_WALL", "WHITE_STONE_FRAME", "TURQUOISE_FLAG", false),
            configureMaterielSetList("BROWN_MONASTERY_ROOF", "BROWN_MONASTERY_WALL", "WHITE_STONE_FRAME", "RED_FLAG", false),
            configureMaterielSetList("BLUE_MONASTERY_ROOF", "BLUE_MONASTERY_WALL", "WHITE_STONE_FRAME", "BLUE_FLAG", false),
            configureMaterielSetList("PURPLE_MONASTERY_ROOF", "PURPLE_MONASTERY_WALL", "WHITE_STONE_FRAME", "GREEN_FLAG", false),
            configureMaterielSetList("WOODEN_MANOR_ROOF", "RED_STONE_WALL", "WHITE_STONE_FRAME", "ORANGE_FLAG", false),
            configureMaterielSetList("RED_SHINGLE_ROOF", "GIANT_GATE_WALL", "WHITE_STONE_FRAME", "PURPLE_FLAG", false),
            configureMaterielSetList("STRAW_ROOF", "WHITE_CHALK_WALL", "WHITE_STONE_FRAME", "TURQUOISE_FLAG", false),
            configureMaterielSetList("RED_TILE_ROOF", "SAND_STONE_WALL", "WHITE_STONE_FRAME", "RED_FLAG", false),
            configureMaterielSetList("BROWN_TILE_ROOF", "SAND_STONE_WALL", "WHITE_STONE_FRAME", "BLUE_FLAG", false),
            configureMaterielSetList("STRAW_ROOF", "WOOD_WALL", "WOOD_FRAME", "GREEN_FLAG", false),
    },
    IsEditable = true
})

CustomDecoration:registerAsset({
	DataType = "UNLOCKABLE",
	Id = _PrefixAsset .. "_UNLOCKABLE",
	Name = _PrefixAsset .. "_UNLOCKABLE_NAME",
	Description = _PrefixAsset .. "_UNLOCKABLE_DESC",
	DataCost = {
		DataInfluenceCostList = {},
		ResourceCollection = {
			{ Resource = "GOLD_COINS", Quantity = 0 },
		}
	},
	PrerequisiteUnlockableList = {},
	ActionList = {
		{
			DataType = "GAME_ACTION_UNLOCK_BUILDING_LIST",
			BuildingProgressData = {
				AssetBuildingList = {
					_PrefixAsset .. "_MONUMENT",
				},
			},
		},
	},
})
-- Override default common progress tiers
CustomDecoration:overrideAsset({
	Id = "PROGRESS_TIER_COMMON_T1",
	UnlockableList = {
		Action = "APPEND",
		_PrefixAsset .."_UNLOCKABLE",
	},
})

-- Adds Stained glasses to the vanilla Church
CustomDecoration:overrideAsset({
    Id = "MONUMENT_CHURCH",
    AssetBuildingPartList = {
                Action = "APPEND",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_WINDOW_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_3_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_4_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_8_PART",
                            _CommonChurchPrefix .. "_DECORATION_SPLENDOR_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_P_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_2_PART",
    }
})

